@@ -5,7 +5,7 @@ from .blueprint import bp_wrappers
 import os
 
 def start_server():
-    app = Sanic()
+    app = Sanic('eiooie')
     # bp_view=bp_wrappers.wrap_md_viewer(Blueprint('bp_view',url_prefix='/'))
     # app.blueprint(bp_view)
     app=bp_wrappers.wrap_md_viewer(app)
